#!/bin/sh -e

ASM="uxncli $HOME/roms/drifblim.rom"
EMU="uxnemu"
LIN="uxncli $HOME/roms/uxnlin.rom"
APP="$HOME/bin/butler push"

SRC="src/oquonie.tal"
DST="bin/oquonie.rom"
CPY="$HOME/roms"
ARG=""
APPID="hundredrabbits/oquonie:uxn"

mkdir -p bin

if [[ "$*" == *"--assets"* ]]
then
	uxnasm etc/tools/packer.tal bin/packer.rom

	echo "Create characters"
	cat etc/c.txt | uxncli bin/packer.rom bin/c.rom
	echo "Create characters(2)"
	cat etc/c2.txt | uxncli bin/packer.rom bin/c2.rom
	echo "Create floors"
	cat etc/f.txt | uxncli bin/packer.rom bin/f.rom
	# Merge floors with c2
	cat bin/c2.rom bin/f.rom > bin/c3.rom && mv bin/c3.rom bin/c2.rom

	echo "Create walls"
	cat etc/w.txt | uxncli bin/packer.rom bin/w.rom
	echo "Create maps"
	cat etc/m.txt | uxncli bin/packer.rom bin/m.rom
	# Merge walls and maps
	cat bin/w.rom bin/m.rom > bin/wm.rom

	echo "Create blockers"
	cat etc/b.txt | uxncli bin/packer.rom bin/b.rom
	echo "Create events"
	cat etc/e.txt | uxncli bin/packer.rom bin/e.rom

	echo "Create portraits"
	cat etc/p.txt | uxncli bin/packer.rom bin/p.rom
	echo "Create camilare"
	cat etc/a.txt | uxncli bin/packer.rom bin/a.rom
	# Merge portraits and camilare
	cat bin/p.rom bin/a.rom > bin/pc.rom

	echo "Padding assets"
	truncate -s 65536 bin/wm.rom
	truncate -s 65536 bin/c.rom
	truncate -s 65536 bin/c2.rom
	truncate -s 65536 bin/b.rom
	truncate -s 65536 bin/e.rom
	truncate -s 65536 bin/pc.rom
fi

if [[ "$*" == *"--lint"* ]]
then
	$LIN $SRC
fi

$ASM $SRC $DST

truncate -s 65280 $DST

cat $DST bin/wm.rom bin/c.rom bin/c2.rom bin/b.rom bin/e.rom bin/pc.rom > bin/result.rom

wc -c bin/result.rom

rm $DST
mv bin/result.rom $DST

if [[ "$*" == *"--save"* ]]
then
	cp $DST $CPY
fi

if [[ "$*" == *"--push"* ]]
then
	$APP $DST $APPID
fi

$EMU -2x $DST $ARG

